@@ -25,14 +25,14 @@ class CDRAdmin(ExportMixin, admin.ModelAdmin):
                        ('start_time', 'direction', 'call_class'),
                        ('callee_number', 'callee_destination'),
                        ('caller_number', 'caller_destination'),
-                       ('duration', 'billsec'))
+                       'duration')
         }),
         (_(u'Advanced date / duration infos'), {
             'fields': (('answered_time', 'end_time'))
         }),
         (_(u'Financial infos'), {
-            'fields': (('total_cost', 'cost_rate'),
-                       ('total_sell', 'rate'))
+            'fields': (('total_cost', 'cost_rate', 'billsec'),
+                       ('total_sell', 'rate', 'costsec'))
         }),
         (_(u'Call detailed infos'), {
             'fields': (('sip_rtp_rxstat', 'sip_rtp_txstat'),
