@@ -119,7 +119,8 @@ class CDR(UUIDModel):
     answered_time = models.DateTimeField(_(u"answered time"), null=True)
     end_time = models.DateTimeField(_(u"hangup time"))
     duration = models.DecimalField(_(u"call duration"), max_digits=13, decimal_places=3, default=0, help_text=_(u"effective call duration in s."))
-    billsec = models.IntegerField(_(u"billed duration"), default=0, help_text=_(u"billed call duration in s."))
+    billsec = models.IntegerField(_(u"customer billed duration"), default=0, help_text=_(u"billed call duration in sec for customer"))
+    costsec = models.IntegerField(_(u"provider billed duration"), default=0, help_text=_(u"billed call duration in sec by provider"))
     read_codec = models.CharField(_(u"read codec"), max_length=20, default="")
     write_codec = models.CharField(_(u"write codec"), max_length=20, default="")
     sip_code = models.CharField(_(u"hangup SIP code"), max_length=3, default="", db_index=True)
